##  Starting a Synchronization Run
With the id of the synchronization run, you can start a synchronization by making a POST request to the following endpoint:

```
https://{SUBDOMAIN}.leanix.net/services/integration-api/v1/synchronizationRuns/{id}/start
```



